pub struct HeightField { /* private fields */ }Expand description
A 3D heightfield.
Implementations
Sourceimpl HeightField
impl HeightField
Sourceimpl HeightField
impl HeightField
Sourcepub fn bounding_sphere(&self, pos: &Pose) -> BoundingSphere
pub fn bounding_sphere(&self, pos: &Pose) -> BoundingSphere
Computes the world-space bounding sphere of this height-field, transformed by pos.
Sourcepub fn local_bounding_sphere(&self) -> BoundingSphere
pub fn local_bounding_sphere(&self) -> BoundingSphere
Computes the local-space bounding sphere of this height-field.
Sourceimpl HeightField
impl HeightField
Sourcepub fn new(heights_zx: Array2<f32>, scale: Vector) -> Self
pub fn new(heights_zx: Array2<f32>, scale: Vector) -> Self
Initializes a new heightfield with the given heights, scaling factor, and flags.
The heights are specified in such a way that the row index i of the array advances
grid coordinates along the z axis, and the column index j of the array advances
grid coordinates along the x axis.
Sourcepub fn with_flags(
heights_zx: Array2<f32>,
scale: Vector,
flags: HeightFieldFlags,
) -> Self
pub fn with_flags( heights_zx: Array2<f32>, scale: Vector, flags: HeightFieldFlags, ) -> Self
Initializes a new heightfield with the given heights and a scaling factor.
Sourceimpl HeightField
impl HeightField
Sourcepub fn closest_cell_at_point(&self, pt: Vector) -> (usize, usize)
pub fn closest_cell_at_point(&self, pt: Vector) -> (usize, usize)
The pair of index of the cell containing the vertical projection of the given point.
Sourcepub fn cell_at_point(&self, pt: Vector) -> Option<(usize, usize)>
pub fn cell_at_point(&self, pt: Vector) -> Option<(usize, usize)>
The pair of index of the cell containing the vertical projection of the given point.
Sourcepub fn unclamped_cell_at_point(&self, pt: Vector) -> (isize, isize)
pub fn unclamped_cell_at_point(&self, pt: Vector) -> (isize, isize)
The pair of index of the cell containing the vertical projection of the given point.
Sourcepub fn x_at(&self, j: usize) -> f32
pub fn x_at(&self, j: usize) -> f32
The smallest x coordinate of the j-th column of this heightfield.
Sourcepub fn z_at(&self, i: usize) -> f32
pub fn z_at(&self, i: usize) -> f32
The smallest z coordinate of the start of the i-th row of this heightfield.
Sourcepub fn signed_x_at(&self, j: isize) -> f32
pub fn signed_x_at(&self, j: isize) -> f32
The smallest x coordinate of the j-th column of this heightfield.
Sourcepub fn signed_z_at(&self, i: isize) -> f32
pub fn signed_z_at(&self, i: isize) -> f32
The smallest z coordinate of the start of the i-th row of this heightfield.
Sourcepub fn triangles(&self) -> impl Iterator<Item = Triangle> + '_
pub fn triangles(&self) -> impl Iterator<Item = Triangle> + '_
An iterator through all the triangles of this heightfield.
Sourcepub fn triangles_around_point(
&self,
point: Vector,
) -> HeightFieldRadialTriangles<'_>
pub fn triangles_around_point( &self, point: Vector, ) -> HeightFieldRadialTriangles<'_>
An iterator through all the triangles around the given point, after vertical projection on the heightfield.
Sourcepub fn triangle_at_id(&self, id: u32) -> Option<Triangle>
pub fn triangle_at_id(&self, id: u32) -> Option<Triangle>
Gets the vertices of the triangle identified by id.
Sourcepub fn triangle_vids_at_id(&self, id: u32) -> Option<[u32; 3]>
pub fn triangle_vids_at_id(&self, id: u32) -> Option<[u32; 3]>
Gets the vertex indices of the triangle identified by id.
Sourcepub fn triangles_vids_at(
&self,
i: usize,
j: usize,
) -> (Option<[u32; 3]>, Option<[u32; 3]>)
pub fn triangles_vids_at( &self, i: usize, j: usize, ) -> (Option<[u32; 3]>, Option<[u32; 3]>)
Gets the indices of the vertices of the (up to) two triangles for the cell (i, j).
Sourcepub fn triangles_at(
&self,
i: usize,
j: usize,
) -> (Option<Triangle>, Option<Triangle>)
pub fn triangles_at( &self, i: usize, j: usize, ) -> (Option<Triangle>, Option<Triangle>)
The two triangles at the cell (i, j) of this heightfield.
Returns None fore triangles that have been removed because of their user-defined status
flags (described by the HeightFieldCellStatus bitfield).
Sourcepub fn triangle_normal_constraints(
&self,
id: u32,
) -> Option<TrianglePseudoNormals>
pub fn triangle_normal_constraints( &self, id: u32, ) -> Option<TrianglePseudoNormals>
Computes the pseudo-normals of the triangle identified by the given id.
Returns None if the heightfield’s HeightFieldFlags::FIX_INTERNAL_EDGES isn’t set, or
if the triangle doesn’t exist due to it being removed by its status flag
(HeightFieldCellStatus::LEFT_TRIANGLE_REMOVED or
HeightFieldCellStatus::RIGHT_TRIANGLE_REMOVED).
Sourcepub fn num_cells_ij(&self) -> (usize, usize)
pub fn num_cells_ij(&self) -> (usize, usize)
The number of cells of this heightfield along each dimension.
Sourcepub fn cell_status(&self, i: usize, j: usize) -> HeightFieldCellStatus
pub fn cell_status(&self, i: usize, j: usize) -> HeightFieldCellStatus
The status of the (i, j)-th cell.
Sourcepub fn set_cell_status(
&mut self,
i: usize,
j: usize,
status: HeightFieldCellStatus,
)
pub fn set_cell_status( &mut self, i: usize, j: usize, status: HeightFieldCellStatus, )
Set the status of the (i, j)-th cell.
Sourcepub fn cells_statuses(&self) -> &Array2<HeightFieldCellStatus>
pub fn cells_statuses(&self) -> &Array2<HeightFieldCellStatus>
The statuses of all the cells of this heightfield.
Sourcepub fn cells_statuses_mut(&mut self) -> &mut Array2<HeightFieldCellStatus>
pub fn cells_statuses_mut(&mut self) -> &mut Array2<HeightFieldCellStatus>
The mutable statuses of all the cells of this heightfield.
Sourcepub fn flags(&self) -> HeightFieldFlags
pub fn flags(&self) -> HeightFieldFlags
The heightfield’s flags controlling internal-edges handling.
Sourcepub fn set_flags(&mut self, flags: HeightFieldFlags)
pub fn set_flags(&mut self, flags: HeightFieldFlags)
Sets the heightfield’s flags controlling internal-edges handling.
Sourcepub fn set_scale(&mut self, new_scale: Vector)
pub fn set_scale(&mut self, new_scale: Vector)
Sets the scale factor applied to this heightfield.
Sourcepub fn cell_width(&self) -> f32
pub fn cell_width(&self) -> f32
The width (extent along its local x axis) of each cell of this heightmap, including the scale factor.
Sourcepub fn cell_height(&self) -> f32
pub fn cell_height(&self) -> f32
The height (extent along its local z axis) of each cell of this heightmap, including the scale factor.
Sourcepub fn unit_cell_width(&self) -> f32
pub fn unit_cell_width(&self) -> f32
The width (extent along its local x axis) of each cell of this heightmap, excluding the scale factor.
Sourcepub fn unit_cell_height(&self) -> f32
pub fn unit_cell_height(&self) -> f32
The height (extent along its local z axis) of each cell of this heightmap, excluding the scale factor.
Sourcepub fn convert_triangle_feature_id(
&self,
i: usize,
j: usize,
left: bool,
fid: FeatureId,
) -> FeatureId
pub fn convert_triangle_feature_id( &self, i: usize, j: usize, left: bool, fid: FeatureId, ) -> FeatureId
Converts the FeatureID of the left or right triangle at the cell (i, j) into a FeatureId
of the whole heightfield.
Sourceimpl HeightField
impl HeightField